#
# spec file for package kdevelop5-plugin-php
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define rname   kdev-php
%bcond_without released
Name:           kdevelop5-plugin-php
Version:        24.05.1
Release:        1.0.2.1.sr20240605
Summary:        PHP plugin for Kdevelop5 Integrated Development Environment
License:        GPL-2.0-or-later
URL:            https://www.kdevelop.org
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{rname}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{rname}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  extra-cmake-modules
BuildRequires:  kcmutils-devel
BuildRequires:  kdevelop5-pg-qt
BuildRequires:  kdevplatform-devel
BuildRequires:  kf5-filesystem
BuildRequires:  ki18n-devel
BuildRequires:  ktexteditor-devel
BuildRequires:  pkgconfig
BuildRequires:  threadweaver-devel
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
Requires:       kdevelop5
Recommends:     %{name}-lang
Conflicts:      kdevelop4-plugin-php
# Only build on archs where Qt5WebEngine is available
ExcludeArch:    ppc ppc64 ppc64le s390 s390x

%description
PHP plugin for Kdevelop Integrated Development Environment

This plugin enables support for the following features for developing
web applications in PHP using Kdevelop5.

  * PHP built-in functions, classes, constants, superglobals
  * user-defined functions, classes, constants, superglobals, variables, etc.
  * proper code completion for objects which respects access modifiers (private,
    public, protected) and differentiates between static/non-static members and
    methods
  * code completion for overridable and implementable functions inside classes
  * hints in the argument list of function- and method class
  * sane code completion after keywords such as extends, implements, catch(),
    new, throw and some more

%package devel
Summary:        Development package for kdevelop5-plugin-php
Requires:       kdevelop5-plugin-php = %{version}

%description devel
This package contains the development files needed in order to use the
kdevelop5-plugin-php API.

%package lang
Summary:        Translations for package %{name}
Requires:       %{name} = %{version}
Supplements:    packageand(bundle-lang-other:%{name})
# Language file conflicts
Conflicts:      kdevelop4-plugins-php
Conflicts:      kdevelop4-plugins-php-doc
Provides:       %{name}-lang-all = %{version}
BuildArch:      noarch

%description lang
Provides translations to the package %{name}

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build

%find_lang kdevphp %{name}.lang

%ldconfig_scriptlets

%files
%license LICENSES/*
%doc AUTHORS HACKING TODO
%{_kf5_appstreamdir}/org.kde.kdev-php.metainfo.xml
%{_kf5_debugdir}/kdevphpsupport.categories
%{_kf5_libdir}/*.so*
%{_kf5_plugindir}/
%{_kf5_servicesdir}/
%{_kf5_sharedir}/kdev*/

%files devel
%{_includedir}/kdev-php/
%{_kf5_cmakedir}/KDevPHP/

%files lang -f %{name}.lang

%changelog
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- No code change since 24.05.0
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- No code change since 24.04.80
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- No code change since 24.02.2
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- No code change since 24.02.1
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- No code change since 24.02.0
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- No code change since 24.01.95
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- No code change since 23.08.2
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- No code change since 23.08.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- No code change since 23.07.80
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Changes since 23.04.3:
  * Add unit tests for grouped namespaces (kde#411588)
  * Syntax support for grouped namespaces
  * Add support for PHP 8.0's trailing comma in closure use lists (kde#459665)
  * Add support for PHP 7.3's trailing comma in function calls (kde#459655)
  * Add support for PHP 8.0's trailing comma in function parameter lists (kde#459664)
  * Add explicit moc includes to sources for moc-covered headers
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- No code change since 23.04.1
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- No code change since 23.04.0
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Changes since 21.12.3:
  * Add CI
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- No code change since 21.12.2
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- No code change since 21.12.1
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- No code change since 21.12.0
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- No code change since 21.11.90
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- No code change since 21.11.80
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
* Wed Feb  3 2021 wbauer@tmo.at
- Update to 5.6.2
  * no code changes
* Wed Dec  9 2020 wbauer@tmo.at
- Update to 5.6.1
  * no code changes
* Tue Sep  8 2020 wbauer@tmo.at
- Update to 5.6.0
  * Update phpfunctions.php to phpdoc revision 350290
  * Support PHP 7.1's syntax for catching multiple exceptions
* Tue Jun  2 2020 wbauer@tmo.at
- Update to 5.5.2
  * Check type before accessing it (kde#421509)
* Tue May  5 2020 wbauer@tmo.at
- Update to 5.5.1
  * Fix a crash when showing the documentation popup
  * Update phpfunctions.php to phpdoc revision 349647
* Mon Feb  3 2020 wbauer@tmo.at
- Update to 5.5.0
  * Fix uses of function call parameters after closures
  * Add support for PHP 7.4's typed properties
  * Support importing functions and constants from other namespaces
    (kde#408609)
  * Fix rename of a variable (kde#317879)
  * Add support for "array of type"
  * Add support for class constant visibility
  * I18n: update message to new default
* Tue Jan  7 2020 wbauer@tmo.at
- Update to 5.4.6
  * Update phpfunctions.php to phpdoc revision 348802
* Mon Dec  2 2019 wbauer@tmo.at
- Update to 5.4.5
  * Update phpfunctions.php to phpdoc revision 34827
* Tue Nov  5 2019 wbauer@tmo.at
- Update to 5.4.4
  * no code changes
* Tue Oct 22 2019 wbauer@tmo.at
- Update to 5.4.3
  * Fix expressions using array constants (kde#405719)
  * Don't mark class constants as normal members
* Tue Sep  3 2019 wbauer@tmo.at
- Update to 5.4.2
  * no code changes
* Tue Aug 13 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.4.1
  * Update phpfunctions.php to phpdoc revision 347831
  * Switch few http URLs to https.
* Tue Aug  6 2019 wbauer@tmo.at
- New upstream release 5.4.0
  * Always set maximum file size for internal parse job
  * Bypass the 5 MB maximum file size limit for the
    phpfunctions.php internal file
  * Fix linking with ld.lld
* Thu Jul 18 2019 wbauer@tmo.at
- New upstream release 5.3.3
  * Use KDE_INSTALL_LOGGINGCATEGORIESDIR for kdebugsettings
    .categories file
  * Update phpfunctions.php to phpdoc revision 347011
  * Parse more function aliases
  * More special handling for mcrypt constants
  * Parse more class constants
  * Parse more constants
  * Parse constants under para
  * Parse more constants within tables
  * Parse url stat constants
  * Parse php token constants
  * Parse file upload constants
  * Parse constants under tables
  * Parse constants under section and within tables
  * Parse nl-langinfo constants
  * Parse constants split over multiple lists within one file
  * Fix function declarations with varargs
* Thu Mar  7 2019 wbauer@tmo.at
- New upstream release 5.3.2
  * no code changes
* Sat Dec 22 2018 wbauer@tmo.at
- New upstream release 5.3.1
  * Fix handling of array indexes after ClassNameReferences
    (kde#401278)
  * Fix syntax support for dynamic member access (kde#400294)
- Run spec-cleaner
* Wed Nov 14 2018 wbauer@tmo.at
- New upstream release 5.3.0
  * Much improved support for PHP Namespaces
  * Added support for Generators and Generator delegation
  * Updated and expanded the integrated documentation of PHP
    internals
  * Added support for PHP 7's context sensitive lexer
  * Install the parser as a library so it can be used by other
    projects (currently, umbrello can use it)
  * Improved type detection of object properties
  * Added support for the object typehint
  * Better support for ClassNameReferences (instanceof)
  * Expression syntax support improvements, particularly around
    'print'
  * Allow optional function parameters before non-optional ones
  * Added support for magic constants __DIR__ and __TRAIT__
- Add devel subpackage
- Remove unnecessary build requirements
* Tue Aug 21 2018 wbauer@tmo.at
- New upstream release 5.2.4
  * Determine correct type for relational and equality expressions
    (kde#305341)
  * Fix a bug with rescheduling jobs
* Fri May 25 2018 wbauer@tmo.at
- New upstream release 5.2.3 (5.2.2 has been skipped)
  * no code changes
- New upstream release 5.2.1
  * Fix a crash when showing navigation tooltip in PHP projects in
    some situations (kde#386969)
- New upstream release 5.2.0
  * For a list of changes, see:
    https://www.kdevelop.org/news/kdevelop-520-released
  * Added support for new language features
  * Work on the type system
  * Bug fixes
- Mark license file as %%license instead of %%doc
* Tue Aug 29 2017 wbauer@tmo.at
- New upstream release 5.1.2
  * Fix a possible crash while parsing PHP code (kde#381123)
* Sat May 27 2017 wbauer@tmo.at
- New upstream release 5.1.1
  * Fix duchain unit tests
* Thu Mar 23 2017 wbauer@tmo.at
- New upstream release 5.1.0
  * For a list of changes, see:
    https://www.kdevelop.org/news/kdevelop-510-released
* Sun Mar  5 2017 wbauer@tmo.at
- New upstream release 5.0.4
  * Update version number to 5.0.4
- Fix a typo in the package description
* Fri Dec  2 2016 wbauer@tmo.at
- New upstream release 5.0.3
  * no code changes
* Wed Nov 16 2016 wbauer@tmo.at
- New upstream release 5.0.2
  * no code changes
* Tue Oct  4 2016 lbeltrame@kde.org
- Remove translations that are no longer there
* Tue Oct  4 2016 lbeltrame@kde.org
- Add BuildRequires to QtConcurrent to fix build
* Mon Oct  3 2016 lbeltrame@kde.org
- New upstream release 5.0.1
  * Fix a crash in the PHP plugin when editing text in the line
    after a "TODO".
* Mon Sep 26 2016 lbeltrame@kde.org
- Tighten Conflicts even more for -lang file conflicts
* Mon Sep 26 2016 lbeltrame@kde.org
- Add Conflicts with kdevelop4-plugin-php (main package and docs)
* Wed Aug 24 2016 cgiboudeaux@gmx.com
- Update to 5.0.0
* Thu Jan 28 2016 tittiatcoke@gmail.com
- Initial package for the PHP plugin for Kdevelop based on Frameworks
  * KDevelop 5 Beta 3
